
<body bgcolor=ffffff>

<table width=100%>
  <tr>
    <td width=10>&nbsp;</td>
    <td>
      <table width=100%>
	<tr>
	  <td>
	    <h4>
	    <%company%>
	    <br><%address%>
	    </h4>
	  </td>
	  <th><img src=http://www.sql-ledger.org/images/sql-ledger.png border=0 width=80 height=58></th>
	  <td align=right>
	  <h4>
	  Tel: <%tel%>
	  <br>Fax: <%fax%>
	  </h4>
	  </td>
	</tr>
	<tr>
	  <th colspan=3><h4>K I M U T A T Á S</h4></th>
	</tr>
	<tr>
	  <td colspan=3 align=right><%statementdate%></td>
	</tr>
      </table>
    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
    <td>
      <table width=100%>
	<tr valign=top>
	  <td><%name%>
	  <br><%address1%>
	  <%if address2%>
<br><%address2%>
<%end address2%>
	  <br><%city%> <%state%> <%zipcode%>
	  <%if country%>
<%country%>
<%end country%>
	  <br>
<%if customerphone%>
	  <br>Tel: <%customerphone%>
<%end customerphone%>
<%if customerfax%>
	  <br>Fax: <%customerfax%>
<%end customerfax%>
<%if email%>
	  <br><%email%>
<%end email%>
	  </td>
	</tr>
      </table>
    </td>
  </tr>
  <tr height=10></tr>
  <tr>
    <td>&nbsp;</td>
    <td>
      <table width=100%>
        <tr>
	  <th align=left>Számla #</th>
	  <th width=15% align=left>Dátum</th>
	  <th width=15% align=left>Esedékesség</th>
	  <th width=10% align=right>0-30</th>
	  <th width=10% align=right>30</th>
	  <th width=10% align=right>60</th>
	  <th width=10% align=right>90+</th>
	</tr>
<%foreach invnumber%>
	<tr>
	  <td align=left><%invnumber%></td>
	  <td align=left><%invdate%></td>
	  <td align=left><%duedate%></td>
	  <td align=right><%c0%></td>
	  <td align=right><%c30%></td>
	  <td align=right><%c60%></td>
	  <td align=right><%c90%></td>
	</tr>
<%end invnumber%>
        <tr>
	  <td colspan=7><hr size=1></td>
	</tr>
	<tr>
	  <td>&nbsp;</td>
	  <td>&nbsp;</td>
	  <td>&nbsp;</td>
	  <th align=right><%c0total%></td>
	  <th align=right><%c30total%></td>
	  <th align=right><%c60total%></td>
	  <th align=right><%c90total%></td>
	</tr>
      </table>
    </td>
  </tr>
  <tr height=10></tr>
  <tr>
    <td>&nbsp;</td>
    <td align=right>
      <table width=50%>
        <tr>
	  <th>Nyitott tételek összesen:</th>
          <th align=right><%total%></th>
	</tr>
      </table>
    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
    <td><hr noshade></td>
  </tr>
  <tr>
    <td>&nbsp;</td>
    <td>Kérjük a fizetendő összeget a <b><%company%></b> bankszámlájára átutalni szíveskedjenek.
    </td>
  </tr>
  <tr height=20></tr>
</table>

