
<body bgcolor=ffffff>

<table width=100%>
  <tr>
    <td width=10>&nbsp;</td>
    
    <td>
      <table width=100%>
	<tr valign=bottom>
	  <td>
	    <h4>
	    <%company%>
	    <br><%address%>
	    </h4>
	  </td>

	  <th><img src=http://www.sql-ledger.org/images/sql-ledger.png border=0 width=64 height=58></th>

	  <td align=right>
	    <h4>
	    電話： <%tel%>
	    <br>傳真： <%fax%>
	    </h4>
	  </td>
	</tr>

	<tr>
	  <th colspan=3>
	    <h4>工作單</h4>
	  </th>
	</tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>

    <td>
      <table width=100% callspacing=0 cellpadding=0>
	<tr bgcolor=000000>
	  <th align=left width=50%><font color=ffffff>致</th>
	  <th align=left width=50%><font color=ffffff>付運往</th>
	</tr>

	<tr valign=top>
	  <td><%name%>
	  <br><%address1%>
	  <%if address2%>
	  <br><%address2%>
	  <%end address2%>
	  <br><%city%> <%state%>
          <br><%zipcode%>
	  <%if country%>
	  <br><%country%>
	  <%end country%>
          <br>
	  <%if contact%>
	  <br>致： <%contact%>
	  <%end contact%>
	  <%if customerphone%>
	  <br>電話： <%customerphone%>
	  <%end customerphone%>
	  <%if customerfax%>
	  <br>傳真： <%customerfax%>
	  <%end customerfax%>
	  <%if email%>
	  <br><%email%>
	  <%end email%>
	  </td>

	  <td><%shiptoname%>
	  <br><%shiptoaddress1%>
	  <%if shiptoaddress2%>
	  <br><%shiptoaddress2%>
	  <%end shiptoaddress2%>
	  <br><%shiptocity%> <%shiptostate%>
          <br><%shiptozipcode%>
	  <%if shiptocountry%>
	  <br><%shiptocountry%>
	  <%end shiptocountry%>
	  <br>
          <%if shiptocontact%>
          <br><%shiptocontact%>
          <%end shiptocontact%>
	  <%if shiptophone%>
	  <br>電話： <%shiptophone%>
	  <%end shiptophone%>
	  <%if shiptofax%>
	  <br>傳真： <%shiptofax%>
	  <%end shiptofax%>
	  <%if shiptoemail%>
	  <br><%shiptoemail%>
	  <%end shiptoemail%>
	  </td>
	</tr>
      </table>
    </td>
  </tr>

  <tr height=5></tr>
  
  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100% border=1>
	<tr>
	  <th width=17% align=left nowrap>訂單編號</th>
	  <th width=17% align=left>落訂日期</th>
	  <th width=17% align=left>要求交付日期</th>
	  <th width=17% align=left nowrap>銷售人員</th>
	  <th width=17% align=left nowrap>付運點</th>
	  <th width=15% align=left nowrap>付運公司</th>
	</tr>

	<tr>
	  <td><%ordnumber%></td>
	  <td><%orddate%></td>
	  <td><%reqdate%></td>
	  <td><%employee%></td>
	  <td><%shippingpoint%>&nbsp;</td>
	  <td><%shipvia%>&nbsp;</td>
	</tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>
 
    <td>
      <table width=100%>
	<tr bgcolor=000000>
	  <th align=right><font color=ffffff>號碼</th>
	  <th align=left><font color=ffffff>號碼</th>
	  <th align=left><font color=ffffff>描述</th>
	  <th><font color=ffffff>數量</th>
	  <th>&nbsp;</th>
           <th><font color=ffffff>箱</th>
	  <th><font color=ffffff>序號</th>
	</tr>

	<%foreach number%>
	<tr valign=top>
          <td align=right><%runningnumber%>.</td>
	  <td><%number%></td>
	  <td><%description%></td>
	  <td align=right><%qty%></td>
	  <td><%unit%></td>
           <td><%bin%></td>
	  <td><%serialnumber%></td>
	</tr>
	<%end number%>

	<tr>
	  <td colspan=7><hr noshade></td>
	</tr>

      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>

    <%if notes%>
    <td><%notes%></td>
    <%end notes%>
  </tr>
</table>

</body>
</html>


