
<body bgcolor=ffffff>

<table width=100%>

  <%include letterhead.html%>
  
  <tr>
    <td width=10>&nbsp;</td>
    
    <th colspan=3><h4>2. U P O M I E N K A</h4></th>
    
  </tr>

  <tr>
    <td>&nbsp;</td>
    
    <td colspan=3 align=right><%statementdate%></td>
  </tr>
  
  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100%>
	<tr valign=top>
	  <td><%name%>
	  <br><%address1%>
	  <%if address2%>
	  <br><%address2%>
	  <%end address2%>
	  <br><%city%>
	  <%if state%>
	  , <%state%>
	  <%end state%>
	  <%zipcode%>
	  <%if country%>
	  <br><%country%>
	  <%end country%>
	  <br>
          <%if customerphone%>
	  <br>Tel: <%customerphone%>
          <%end customerphone%>
          <%if customerfax%>
	  <br>Fax: <%customerfax%>
          <%end customerfax%>
          <%if email%>
	  <br><%email%>
          <%end email%>
	  </td>
	</tr>
      </table>
    </td>
  </tr>
  
  <tr height=10></tr>
  
  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100%>
        <tr>
	  <th>Faktúra</th>
          <th>Objednávka</th>
	  <th>Dátum faktúry</th>
	  <th>Dátum splatnosti</th>
	  <th>Suma</th>
	</tr>
        
	<tr>
	  <td align=center><%invnumber%></td>
          <td align=center><%ordnumber%></td>
	  <td align=center><%invdate%></td>
	  <td align=center><%duedate%></td>
	  <td align=center><%due%></td>
	</tr>
	
        <tr>
	  <td colspan=5><hr size=1></td>
	</tr>
	
      </table>
    </td>
  </tr>
  
  <tr height=10></tr>
  
  <tr>
    <td>&nbsp;</td>
    <td>
    Podľa naších záznamov faktúra číslo <%invnumber%> je po dátume splatnosti. Keď ste platbu už uskutočnili považujte upomienku zy bezpredmetnú.
<p>
    Thank you in advance for your anticipated cooperation in this matter.
    </td>
  </tr>

</table>

</body>
</html>


