
<body bgcolor=ffffff>

<table width=100%>
<tr valign=bottom>
  <td width=10>&nbsp;</td>
  <td>
  
  <table width=100%>
  <tr>
    <td>
      <h4>
      <%company%>
      <br><%address%>
      </h4>
    </td>

    <td align=right>
      <h4>
      Tel: <%tel%>
      <br>Fax: <%fax%>
      </h4>
    </td>
  </tr>

  <tr>
    <th colspan=3>
      <h4>FATTURA</h4>
    </th>
  </tr>

  </table>


  <table width=100% callspacing=0 cellpadding=0>
    
  <tr>
    <td align=right>
    <table>
    <tr>
      <th align=right>Data fattura</th><td width=10>&nbsp;</td><td><%invdate%></td>
    </tr>
  
    <tr>
      <th align=right>Scadenza</th><td width=10>&nbsp;</td><td><%duedate%></td>
    </tr>

    <tr>
      <th align=right>Numero fattura</th><td>&nbsp;</td><td><%invnumber%></td></tr>
    </tr>
  
    <tr>
      <td>&nbsp;</td>
    </tr>
    </td>
    </table>
  </tr>

  <tr>
    <td>
    <table width=100%>
    <tr bgcolor=000000>
      <th align=left><font color=ffffff>Sede legale:</th>
      <th align=left><font color=ffffff>Inviare fattura a:</th>
    </tr>

    <tr>
      <td><%name%>
      <br><%address1%>
      <%if address2%>
<br><%address2%>
<%end address2%>
      <br><%city%> <%state%> <%zipcode%>
      <%if country%>
<%country%>
<%end country%>
      </td>
      
      <td><%shiptoname%>
      <br><%shiptoaddress1%>
      <%if shiptoaddress2%>
<br><%shiptoaddress2%>
<%end shiptoaddress2%>
      <br><%shiptocity%> <%shiptostate%> <%shiptozipcode%>
      <%if shiptocountry%>
<%shiptocountry%>
<%end shiptocountry%>
      </td>
    </tr>
    </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>
  </tr>
  
  <tr>
    <td>
    <table width=100%>
    <tr bgcolor=000000>
<!--      <th align=right><font color=ffffff>No.</th>  -->
      <th align=left><font color=ffffff>Numero</th>
      <th align=left><font color=ffffff>Descrizione</th>
      <th><font color=ffffff>Quantit&agrave;</th>
      <th>&nbsp;</th>
      <th><font color=ffffff>Prezzo</th>
      <th><font color=ffffff>Sconto</th>
      <th><font color=ffffff>Totale riga</th>
    </tr>

<%foreach number%>
    <tr valign=top>
<!--      <td align=right><%runningnumber%>.</td>
adjust the colspan if you include this to shift subtotal one to the right
-->
      <td><%number%></td>
      <td><%description%></td>
      <td align=right><%qty%></td>
      <td><%unit%></td>
      <td align=right><%sellprice%></td>
      <td align=right><%discount%></td>
      <td align=right><%linetotal%></td>
    </tr>
<%end number%>

<!--
you can also use netprice instead of sellprice if you
don't want to show the discount
netprice = sellprice - discount
to show the percentage for a discount use <%discountrate%>
-->

    <tr>
      <td colspan=7><hr noshade></td>
    </tr>
    
    <tr>
      <th colspan=5 align=right>Totale righe</th>
      <td colspan=2 align=right><%subtotal%></td>
    </tr>

<%foreach tax%>
    <tr>
      <th colspan=5 align=right><%taxdescription%>: <%taxrate%>% su <%taxbase%></th>
      <td colspan=2 align=right><%tax%></td>
    </tr>
<%end tax%>

<%if paid%>
    <tr>
      <th colspan=5 align=right>Importo gi&agrave; pagato</th>
      <td colspan=2 align=right>- <%paid%></td>
    </tr>
<%end paid%>

    <tr>
      <td colspan=3>&nbsp;</td>
      <td colspan=4><hr noshade></td>
    </tr>

    <tr>
      <td colspan=3>Scadenza a <b><%terms%></b> giorni data fattura.</td>
      <th colspan=2 align=right>Totale da pagare</th>
      <th colspan=2 align=right><%total%></th>
    </tr>

    <tr>
      <td>&nbsp;</td>
    </tr>

    </table>
    </td>
  </tr>

<tr>
  <td>
  <table width=100%>
    <tr valign=top>
      <td>Note</td>
      <td><%notes%></td>
      <td align=right>
      I prezzi sono espressi in valuta <b><%currency%></b>.
      <br><%shippingpoint%>
      </td>
    </tr>

  </table>
  </td>
</tr>

<tr><td>&nbsp;</td></tr>
  
<tr>
  <td>
    Per i pagamenti successivi alla scadenza della fattura sar&agrave;
    addebitato l'interesse legale, aumentato di due punti percentuali, fino al
    pagamento completo.
  </td>
</tr>

</table>

</td>
</tr>
</table>

</body>
</html>
