
<body bgcolor=ffffff>

<table width=100%>

  <%include letterhead.html%>
  
  <tr>
    <td width=10>&nbsp;</td>
  
    <th colspan=3>
      <h4>P U R C H A S E &nbsp;&nbsp; O R D E R</h4>
    </th>
  </tr>

  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100% callspacing=0 cellpadding=0>
	<tr bgcolor=000000>
	  <th align=left width=50%><font color=ffffff>To:</th>
	  <th align=left width=50%><font color=ffffff>Ship To:</th>
	</tr>

	<tr valign=top>
	  <td><%name%>
	  <br><%address1%>
	  <%if address2%>
	  <br><%address2%>
	  <%end address2%>
	  <br><%city%>
	  <%if state%>
	  , <%state%>
	  <%end state%>
	  <%zipcode%>
	  <%if country%>
	  <br><%country%>
	  <%end country%>
          <br>

	  <%if contact%>
	  <br>Attn: <%contact%>
	  <%end contact%>
	  
	  <%if vendorphone%>
	  <br>Tel: <%vendorphone%>
	  <%end vendorphone%>
	  
	  <%if vendorfax%>
	  <br>Fax: <%vendorfax%>
	  <%end vendorfax%>
	  </td>

	  <td><%shiptoname%>
	  <br><%shiptoaddress1%>
	  <%if shiptoaddress2%>
	  <br><%shiptoaddress2%>
	  <%end shiptoaddress2%>
	  <br><%shiptocity%>
	  <%if shiptostate%>
	  , <%shiptostate%>
	  <%end shiptostate%>
	  <%shiptozipcode%>
	  <%if shiptocountry%>
	  <br><%shiptocountry%>
	  <%end shiptocountry%>
          <br>

	  <%if shiptocontact%>
	  <br>Attn: <%shiptocontact%>
	  <%end shiptocontact%>
	  
	  <%if shiptophone%>
	  <br>Tel: <%shiptophone%>
	  <%end shiptophone%>
	  
	  <%if shiptofax%>
	  <br>Fax: <%shiptofax%>
	  <%end shiptofax%>
	  </td>
	</tr>
      </table>
    </td>
  </tr>

  <tr height=5></tr>

  <tr>
    <td>&nbsp;</td>

    <td>
      <table width=100% border=1>
	<tr>
	  <th width=17% align=left>Order #</th>
	  <th width=17% align=left>Order Date</th>
	  <th width=17% align=left>Required by</th>
	  <th width=17% align=left>Contact</th>
	  <th width=17% align=left>Shipping Point</th>
	  <th width=15% align=left>Ship Via</th>
	</tr>

	<tr>
	  <td><%ordnumber%></td>
	  <td><%orddate%></td>
	  <td><%reqdate%></td>
	  <td><%employee%></td>
	  <td><%shippingpoint%>&nbsp;</td>
	  <td><%shipvia%>&nbsp;</td>
	</tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100%>
	<tr bgcolor=000000>
	  <th align=right><font color=ffffff>Item</th>
	  <th align=left><font color=ffffff>Number</th>
	  <th align=left><font color=ffffff>Description</th>
	  <th><font color=ffffff>Qt'y</th>
	  <th>&nbsp;</th>
	  <th><font color=ffffff>Price</th>
	  <th><font color=ffffff>%</th>
	  <th><font color=ffffff>Amount</th>
	</tr>

        <%foreach number%>
	<tr valign=top>
	  <td align=right><%runningnumber%>.</td>
	  <td><%number%></td>
	  <td><%description%></td>
	  <td align=right><%qty%></td>
	  <td><%unit%></td>
	  <td align=right><%sellprice%></td>
	  <td align=right><%discountrate%></th>
	  <td align=right><%linetotal%></td>
	</tr>
        <%end number%>

	<tr>
	  <td colspan=8><hr noshade></td>
	</tr>
	
	<tr>
          <%if taxincluded%>
	  <th colspan=7 align=right>Total</th>
	  <th colspan=1 align=right><%ordtotal%></th>
          <%end taxincluded%>
	 
          <%if not taxincluded%>
	  <th colspan=7 align=right>Subtotal</th>
	  <td colspan=1 align=right><%subtotal%></td>
          <%end taxincluded%>
	</tr>

        <%foreach tax%>
	<tr>
	  <th colspan=7 align=right><%taxdescription%> on <%taxbase%> @ <%taxrate%> %</th>
	  <td colspan=1 align=right><%tax%></td>
	</tr>
        <%end tax%>

	<tr>
	  <td colspan=4>&nbsp;</td>
	  <td colspan=4><hr noshade></td>
	</tr>
	
        <%if not taxincluded%>
	  <th colspan=7 align=right>Total</th>
	  <td colspan=1 align=right><%ordtotal%></td>
        <%end taxincluded%>

        <%if terms%>
	<tr>
	  <td colspan=4>Terms Net <b><%terms%></b> days</td>
	  <th colspan=3 align=right>Total</th>
	  <th colspan=1 align=right><%ordtotal%></th>
	</tr>
        <%end terms%>

        <%if taxincluded%>
	<tr>
	  <td colspan=2>Tax included</td>
	</tr>
        <%end taxincluded%>

	<tr>
	  <td>&nbsp;</td>
	</tr>
	
        <%if ordtotal%>
	<tr>
	  <td colspan=8 align=right>
	  All prices in <b><%currency%></b> Funds
	  </td>
	</tr>
        <%end ordtotal%>

      </table>
    </td>
  </tr>

  <%if notes%>
  <tr>
    <td>&nbsp;</td>
    
    <td>
    <table width=100%>
      <tr valign=top>
	<td>Notes</td>
	<td><%notes%></td>
      </tr>

    </table>
    </td>
  </tr>
  <%end notes%>

  <tr>
    <td>&nbsp;</td>
  
    <td>
      <table width=100%>
	<tr valign=top>
	  <td width=70%>&nbsp;</td>

	  <td width=30%>
	  X <hr noshade>
	  </td>
	</tr>
      </table>
    </td>
  </tr>

</table>

</body>
</html>

