<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional">

<html>

<head>

<title>Bilan</title>
<meta HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=iso-8859-15">

</head>

<body bgcolor=ffffff>

<h2 align=center>
<%company%>
<br><%address%>

<p>BILAN DE VÉRIFICATION
<br><%period%>
</h2>

<table border=0>
<tr>
  <th align=left width=400 colspan=2>ACTIF<br><hr align=left width=250 size=5 noshade></th>
  <th><%this_period%></th>
  <th><%last_period%></th>
</tr>

<%foreach asset_account%>
<tr>
  <td> </td>
  <td><%asset_account%></td>
  <td align=right><%asset_this_period%></td>
  <td align=right><%asset_last_period%></td>
</tr>
<%end asset_account%>

<tr>
  <td colspan=2> </td>
  <td><hr noshade size=1></td>
  <td><hr noshade size=1></td>
</tr>

<tr valign=top>
  <th align=left colspan=2>Total Actif</th>
  <td align=right><%total_assets_this_period%><hr noshade size=2></td>
  <td align=right><%total_assets_last_period%><hr noshade size=2></td>
</tr>

<tr>
  <th align=left colspan=4>PASSIF<b><hr align=left width=250 size=5 noshade></th>
</tr>

<%foreach liability_account%>
<tr>
  <td></td>
  <td><%liability_account%></td>
  <td align=right><%liability_this_period%></td>
  <td align=right><%liability_last_period%></td>
</tr>
<%end liability_account%>

<tr>
  <td colspan=2> </td>
  <td><hr noshade size=1></td>
  <td><hr noshade size=1></td>
</tr>

<tr valign=top>
  <td></td>
  <th align=left>Total Passif</th>
  <td align=right><%total_liabilities_this_period%><br><hr noshade size=2</td>
  <td align=right><%total_liabilities_last_period%><br><hr noshade size=2</td>
</tr>

<tr>
  <th align=left colspan=4>BENEFICES NON DISTRIBUÉS<br><hr align=left width=250 size=5 noshade></th>
</tr>

<%foreach equity_account%>
<tr>
  <td></td>
  <td><%equity_account%></td>
  <td align=right><%equity_this_period%></td>
  <td align=right><%equity_last_period%></td>
</tr>
<%end equity_account%>

<tr>
  <td colspan=2> </td>
  <td><hr noshade size=1></td>
  <td><hr noshade size=1></td>
</tr>

<tr valign=top>
  <td></td>
  <th align=left>Total Capital</th>
  <td align=right><%total_equity_this_period%><br><hr noshade size=2</td>
  <td align=right><%total_equity_last_period%><br><hr noshade size=2</td>
</tr>

<tr valign=top>
  <th align=left colspan=2>TOTAL PASSIF & CAPITAL</th>
  <td align=right><%total_this_period%><br><hr noshade size=2></td>
  <td align=right><%total_last_period%><br><hr noshade size=2></td>
</tr>
</table>
</body>
</html>
