
<body bgcolor=ffffff>

<table width=100%>
  <tr>
    <td width=10>&nbsp;</td> 
    
    <td>
      <table width=100%>
	<tr>
	  <td>
	    <h4>
	    <%company%>
	    <br><%address%>
	    </h4>
	  </td>

	  <th><img src=http://www.sql-ledger.org/images/sql-ledger.png border=0 width=64 height=58></th>

	  <td align=right>
	    <h4>
	    電話： <%tel%>
	    <br>傳真： <%fax%>
	    </h4>
	  </td>
	</tr>

	<tr>
	  <th colspan=3>
	    <h4>出貨單</h4>
	  </th>
	</tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>

    <td>
      <table width=100% cellspacing=0 cellpadding=0>
	<tr bgcolor=000000>
	  <th width=50% align=left><font color=ffffff>付運往：</th>
	  <th width=50%>&nbsp;</th>
	</tr>

	<tr valign=top>
	  <td><%shiptoname%>
	  <br><%shiptoaddress1%>
	  <%if shiptoaddress2%>
	  <br><%shiptoaddress2%>
	  <%end shiptoaddress2%>
	  <br><%shiptocity%> <%shiptostate%> <%shiptozipcode%>
	  <%if shiptocountry%>
	  <br><%shiptocountry%>
	  <%end shiptocountry%>
	  </td>
	
	  <td>
	  <%if shiptocontact%>
	  <br>致：<%shiptocontact%>
	  <%end shiptocontact%>
	  
	  <%if shiptophone%>
	  <br>電話： <%shiptophone%>
	  <%end shiptophone%>
	  
	  <%if shiptofax%>
	  <br>傳真： <%shiptofax%>
	  <%end shiptofax%>

	  <%shiptoemail%>
	  </td>
	</tr>
      </table>
    </td>
  </tr>

  <tr height=5></tr>
  
  <tr>
    <td>&nbsp;</td>

    <td>
      <table width=100% border=1>
	<tr>
	  <th width=17% align=left>發票編號</th>
	  <th width=17% align=left>訂單編號</th>
	  <th width=17% align=left>日期</th>
	  <th width=17% align=left nowrap>聯絡人</th>
	  <%if warehouse%>
	  <th width=17% align=left>倉庫</th>
	  <%end warehouse%>
	  <th width=17% align=left>付運點</th>
	  <th width=15% align=left>付運公司</th>
	</tr>

        <tr>
	  <td><%invnumber%>&nbsp;</td>
	  <td><%ordnumber%>&nbsp;</td>
	  
	  <%if shippingdate%>
	  <td><%shippingdate%></td>
	  <%end shippingdate%>
	  
	  <%if not shippingdate%>
	  <td><%transdate%></td>
	  <%end shippingdate%>
  
          <td><%employee%>&nbsp;</td>
	  
	  <%if warehouse%>
	  <td><%warehouse%>&nbsp;</td>
	  <%end warehouse%>

	  <td><%shippingpoint%>&nbsp;</td>
	  <td><%shipvia%>&nbsp;</td>
	</tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>

    <td>
      <table width=100%>
	<tr bgcolor=000000>
	  <th align=left><font color=ffffff>位置</th>
	  <th align=left><font color=ffffff>編號</th>
	  <th align=left><font color=ffffff>描述</th>
	  <th align=left><font color=ffffff>序號</th>
	  <th>&nbsp;</th>
	  <th><font color=ffffff>數量</th>
	  <th><font color=ffffff>付運</th>
	  <th>&nbsp;</th>
	</tr>

	<%foreach number%>
	<tr valign=top>
	  <td><%runningnumber%></td>
	  <td><%number%></td>
	  <td><%description%></td>
	  <td><%serialnumber%></td>
	  <td><%deliverydate%></td>
	  <td align=right><%qty%></td>
	  <td align=right><%ship%></td>
	  <td><%unit%></td>
	</tr>
	<%end number%>

      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>

    <td><hr noshade></td>
  </tr>

  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100%>
	<tr valign=top>
	  <td>備註</td>
	  <td><%notes%></td>
	</tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>&nbsp;</td>
    
    <td>
      <table width=100%>
	<tr valign=top>
	  <td width=70%><font size=-3>
退回的物品須支付10%的回收費用。若要退回物品，必須先取得<%company%>的授權。退回
物品的運費和保險費自負。若在途中出現有損毀情況，<%company%>將不會負任何責任。
	  </font>
	  </td>
	  <td width=30%>
	  X <hr noshade>
	  </td>
	</tr>
      </table>
    </td>
  </tr>
</table>

